@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2013 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2015 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -30,8 +30,11 @@ class CConfig;
 class CClient;
 class CConfig;
 class CChan;
+class CQuery;
 class CServer;
 class CIRCSock;
+class CIRCNetworkPingTimer;
+class CIRCNetworkJoinTimer;
 
 class CIRCNetwork {
 public:
@@ -41,14 +44,26 @@ public:
 	CIRCNetwork(CUser *pUser, const CIRCNetwork& Network);
 	~CIRCNetwork();
 
+	enum {
+		JOIN_FREQUENCY = 30,
+		/** How long must an IRC connection be idle before ZNC sends a ping */
+		PING_FREQUENCY = 270,
+		/** Time between checks if PINGs need to be sent */
+		PING_SLACK = 30,
+		/** Timeout after which IRC connections are closed. Must
+		 *  obviously be greater than PING_FREQUENCY + PING_SLACK.
+		 */
+		NO_TRAFFIC_TIMEOUT = 540
+	};
+
 	void Clone(const CIRCNetwork& Network, bool bCloneName = true);
 
-	CString GetNetworkPath();
+	CString GetNetworkPath() const;
 
 	void DelServers();
 
 	bool ParseConfig(CConfig *pConfig, CString& sError, bool bUpgrade = false);
-	CConfig ToConfig();
+	CConfig ToConfig() const;
 
 	void BounceAllClients();
 
@@ -57,10 +72,11 @@ public:
 	void ClientConnected(CClient *pClient);
 	void ClientDisconnected(CClient *pClient);
 
-	CUser* GetUser();
+	CUser* GetUser() const;
 	const CString& GetName() const;
-	bool IsNetworkAttached() const { return !m_vClients.empty(); };
-	std::vector<CClient*>& GetClients() { return m_vClients; }
+	bool IsNetworkAttached() const { return !m_vClients.empty(); }
+	const std::vector<CClient*>& GetClients() const { return m_vClients; }
+	std::vector<CClient*> FindClients(const CString& sIdentifier) const;
 
 	void SetUser(CUser *pUser);
 	bool SetName(const CString& sName);
@@ -76,14 +92,21 @@ public:
 
 	const std::vector<CChan*>& GetChans() const;
 	CChan* FindChan(CString sName) const;
+	std::vector<CChan*> FindChans(const CString& sWild) const;
 	bool AddChan(CChan* pChan);
 	bool AddChan(const CString& sName, bool bInConfig);
 	bool DelChan(const CString& sName);
 	void JoinChans();
 	void JoinChans(std::set<CChan*>& sChans);
 
-	const CString& GetChanPrefixes() const { return m_sChanPrefixes; };
-	void SetChanPrefixes(const CString& s) { m_sChanPrefixes = s; };
+	const std::vector<CQuery*>& GetQueries() const;
+	CQuery* FindQuery(const CString& sName) const;
+	std::vector<CQuery*> FindQueries(const CString& sWild) const;
+	CQuery* AddQuery(const CString& sName);
+	bool DelQuery(const CString& sName);
+
+	const CString& GetChanPrefixes() const { return m_sChanPrefixes; }
+	void SetChanPrefixes(const CString& s) { m_sChanPrefixes = s; }
 	bool IsChan(const CString& sChan) const;
 
 	const std::vector<CServer*>& GetServers() const;
@@ -98,6 +121,10 @@ public:
 	bool SetNextServer(const CServer* pServer);
 	bool IsLastServer() const;
 
+	const SCString& GetTrustedFingerprints() const { return m_ssTrustedFingerprints; }
+	void AddTrustedFingerprint(const CString& sFP) { m_ssTrustedFingerprints.insert(sFP.Escape_n(CString::EHEXCOLON, CString::EHEXCOLON)); }
+	void DelTrustedFingerprint(const CString& sFP) { m_ssTrustedFingerprints.erase(sFP); }
+
 	void SetIRCConnectEnabled(bool b);
 	bool GetIRCConnectEnabled() const { return m_bIRCConnectEnabled; }
 
@@ -115,6 +142,7 @@ public:
 	 */
 	bool IsIRCConnected() const;
 	void SetIRCSocket(CIRCSock* pIRCSock);
+	void IRCConnected();
 	void IRCDisconnected();
 	void CheckIRCConnect();
 
@@ -130,9 +158,9 @@ public:
 	void UpdateMotdBuffer(const CString& sMatch, const CString& sFormat, const CString& sText = "") { m_MotdBuffer.UpdateLine(sMatch, sFormat, sText); }
 	void ClearMotdBuffer() { m_MotdBuffer.Clear(); }
 
-	void AddQueryBuffer(const CString& sFormat, const CString& sText = "") { m_QueryBuffer.AddLine(sFormat, sText); }
-	void UpdateQueryBuffer(const CString& sMatch, const CString& sFormat, const CString& sText = "") { m_QueryBuffer.UpdateLine(sMatch, sFormat, sText); }
-	void ClearQueryBuffer() { m_QueryBuffer.Clear(); }
+	void AddNoticeBuffer(const CString& sFormat, const CString& sText = "") { m_NoticeBuffer.AddLine(sFormat, sText); }
+	void UpdateNoticeBuffer(const CString& sMatch, const CString& sFormat, const CString& sText = "") { m_NoticeBuffer.UpdateLine(sMatch, sFormat, sText); }
+	void ClearNoticeBuffer() { m_NoticeBuffer.Clear(); }
 	// !Buffers
 
 	// la
@@ -141,22 +169,30 @@ public:
 	const CString& GetIdent(const bool bAllowDefault = true) const;
 	const CString& GetRealName() const;
 	const CString& GetBindHost() const;
+	const CString& GetEncoding() const;
+	CString GetQuitMsg() const;
 
 	void SetNick(const CString& s);
 	void SetAltNick(const CString& s);
 	void SetIdent(const CString& s);
 	void SetRealName(const CString& s);
 	void SetBindHost(const CString& s);
+	void SetEncoding(const CString& s);
+	void SetQuitMsg(const CString& s);
 
 	double GetFloodRate() const { return m_fFloodRate; }
 	unsigned short int GetFloodBurst() const { return m_uFloodBurst; }
 	void SetFloodRate(double fFloodRate) { m_fFloodRate = fFloodRate; }
 	void SetFloodBurst(unsigned short int uFloodBurst) { m_uFloodBurst = uFloodBurst; }
 
+	unsigned short int GetJoinDelay() const { return m_uJoinDelay; }
+	void SetJoinDelay(unsigned short int uJoinDelay) { m_uJoinDelay = uJoinDelay; }
+
 	CString ExpandString(const CString& sStr) const;
 	CString& ExpandString(const CString& sStr, CString& sRet) const;
 private:
 	bool JoinChan(CChan* pChan);
+	bool LoadModule(const CString& sModName, const CString& sArgs, const CString& sNotice, CString& sError);
 
 protected:
 	CString            m_sName;
@@ -167,6 +203,9 @@ protected:
 	CString            m_sIdent;
 	CString            m_sRealName;
 	CString            m_sBindHost;
+	CString            m_sEncoding;
+	CString            m_sQuitMsg;
+	SCString           m_ssTrustedFingerprints;
 
 	CModules*          m_pModules;
 
@@ -175,6 +214,7 @@ protected:
 	CIRCSock*          m_pIRCSock;
 
 	std::vector<CChan*>     m_vChans;
+	std::vector<CQuery*>    m_vQueries;
 
 	CString            m_sChanPrefixes;
 
@@ -191,7 +231,12 @@ protected:
 
 	CBuffer            m_RawBuffer;
 	CBuffer            m_MotdBuffer;
-	CBuffer            m_QueryBuffer;
+	CBuffer            m_NoticeBuffer;
+
+	CIRCNetworkPingTimer* m_pPingTimer;
+	CIRCNetworkJoinTimer* m_pJoinTimer;
+
+	unsigned short int m_uJoinDelay;
 };
 
 #endif // !_IRCNETWORK_H
