@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2015 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -43,44 +43,8 @@ public:
 		DelNV("NickServName");
 	}
 
-	void GhostCommand(const CString& sLine) {
-		if (sLine.Token(1).empty()) {
-			PutModule("Syntax: ghost <nickname>");
-		} else {
-			DoNickCommand("GhostCmd", sLine.Token(1));
-		}
-	}
-
-	void RecoverCommand(const CString& sLine) {
-		if (sLine.Token(1).empty()) {
-			PutModule("Syntax: recover <nickname>");
-		} else {
-			DoNickCommand("RecoverCmd", sLine.Token(1));
-		}
-	}
-
-	void ReleaseCommand(const CString& sLine) {
-		if (sLine.Token(1).empty()) {
-			PutModule("Syntax: release <nickname>");
-		} else {
-			DoNickCommand("ReleaseCmd", sLine.Token(1));
-		}
-	}
-
-	void GroupCommand(const CString& sLine) {
-		if (sLine.Token(1).empty()) {
-			PutModule("Syntax: group <nickname>");
-		} else {
-			DoNickCommand("GroupCmd", sLine.Token(1));
-		}
-	}
-
 	void ViewCommandsCommand(const CString& sLine) {
 		PutModule("IDENTIFY " + GetNV("IdentifyCmd"));
-		PutModule("GHOST " + GetNV("GhostCmd"));
-		PutModule("RECOVER " + GetNV("RecoverCmd"));
-		PutModule("RELEASE " + GetNV("ReleaseCmd"));
-		PutModule("GROUP " + GetNV("GroupCmd"));
 	}
 
 	void SetCommandCommand(const CString& sLine) {
@@ -88,14 +52,6 @@ public:
 		CString sNewCmd = sLine.Token(2, true);
 		if (sCmd.Equals("IDENTIFY")) {
 			SetNV("IdentifyCmd", sNewCmd);
-		} else if (sCmd.Equals("GHOST")) {
-			SetNV("GhostCmd", sNewCmd);
-		} else if (sCmd.Equals("RECOVER")) {
-			SetNV("RecoverCmd", sNewCmd);
-		} else if (sCmd.Equals("RELEASE")) {
-			SetNV("ReleaseCmd", sNewCmd);
-		} else if (sCmd.Equals("GROUP")) {
-			SetNV("GroupCmd", sNewCmd);
 		} else {
 			PutModule("No such editable command. See ViewCommands for list.");
 			return;
@@ -113,14 +69,6 @@ public:
 			"nickname", "Set NickServ name (Useful on networks like EpiKnet, where NickServ is named Themis)");
 		AddCommand("ClearNSName", static_cast<CModCommand::ModCmdFunc>(&CNickServ::ClearNSNameCommand),
 			"", "Reset NickServ name to default (NickServ)");
-		AddCommand("Ghost", static_cast<CModCommand::ModCmdFunc>(&CNickServ::GhostCommand),
-			"nickname", "GHOST disconnects an old user session, or somebody attempting to use your nickname without authorization.");
-		AddCommand("Recover", static_cast<CModCommand::ModCmdFunc>(&CNickServ::RecoverCommand),
-			"nickname");
-		AddCommand("Release", static_cast<CModCommand::ModCmdFunc>(&CNickServ::ReleaseCommand),
-			"nickname");
-		AddCommand("Group", static_cast<CModCommand::ModCmdFunc>(&CNickServ::GroupCommand),
-			"nickname");
 		AddCommand("ViewCommands", static_cast<CModCommand::ModCmdFunc>(&CNickServ::ViewCommandsCommand),
 			"", "Show patterns for lines, which are being sent to NickServ");
 		AddCommand("SetCommand", static_cast<CModCommand::ModCmdFunc>(&CNickServ::SetCommandCommand),
@@ -129,7 +77,7 @@ public:
 
 	virtual ~CNickServ() {}
 
-	virtual bool OnLoad(const CString& sArgs, CString& sMessage) {
+	virtual bool OnLoad(const CString& sArgs, CString& sMessage) override {
 		if (!sArgs.empty() && sArgs != "<hidden>") {
 			SetNV("Password", sArgs);
 			SetArgs("<hidden>");
@@ -138,18 +86,6 @@ public:
 		if (GetNV("IdentifyCmd").empty()) {
 			SetNV("IdentifyCmd", "PRIVMSG NickServ :IDENTIFY {password}");
 		}
-		if (GetNV("GhostCmd").empty()) {
-			SetNV("GhostCmd", "PRIVMSG NickServ :GHOST {nickname} {password}");
-		}
-		if (GetNV("RecoverCmd").empty()) {
-			SetNV("RecoverCmd", "PRIVMSG NickServ :RECOVER {nickname} {password}");
-		}
-		if (GetNV("ReleaseCmd").empty()) {
-			SetNV("ReleaseCmd", "PRIVMSG NickServ :RELEASE {nickname} {password}");
-		}
-		if (GetNV("GroupCmd").empty()) {
-			SetNV("GroupCmd", "PRIVMSG NickServ :GROUP {nickname} {password}");
-		}
 
 		return true;
 	}
@@ -165,7 +101,8 @@ public:
 				 || sMessage.find("If this is your nick, identify yourself with") != CString::npos
 				 || sMessage.find("If this is your nick, type") != CString::npos
 				 || sMessage.find("This is a registered nickname, please identify") != CString::npos
-				 || sMessage.StripControls_n().find("type /NickServ IDENTIFY password") != CString::npos)
+				 || sMessage.StripControls_n().find("type /NickServ IDENTIFY password") != CString::npos
+				 || sMessage.StripControls_n().find("type /msg NickServ IDENTIFY password") != CString::npos)
 				&& sMessage.AsUpper().find("IDENTIFY") != CString::npos
 				&& sMessage.find("help") == CString::npos) {
 			MCString msValues;
@@ -174,12 +111,12 @@ public:
 		}
 	}
 
-	virtual EModRet OnPrivMsg(CNick& Nick, CString& sMessage) {
+	virtual EModRet OnPrivMsg(CNick& Nick, CString& sMessage) override {
 		HandleMessage(Nick, sMessage);
 		return CONTINUE;
 	}
 
-	virtual EModRet OnPrivNotice(CNick& Nick, CString& sMessage) {
+	virtual EModRet OnPrivNotice(CNick& Nick, CString& sMessage) override {
 		HandleMessage(Nick, sMessage);
 		return CONTINUE;
 	}
