@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2015 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -102,14 +102,14 @@ public:
 		}
 	}
 
-	virtual bool OnBoot() {
+	virtual bool OnBoot() override {
 		// The config is now read completely, so all Users are set up
 		Load();
 
 		return true;
 	}
 
-	virtual bool OnLoad(const CString& sArgs, CString& sMessage) {
+	virtual bool OnLoad(const CString& sArgs, CString& sMessage) override {
 		const map<CString, CUser*>& msUsers = CZNC::Get().GetUserMap();
 
 		for (map<CString, CUser*>::const_iterator it = msUsers.begin(); it != msUsers.end(); ++it) {
@@ -175,7 +175,7 @@ public:
 			DelNV("topic:" + pChannel->GetName());
 	}
 
-	virtual EModRet OnDeleteUser(CUser& User) {
+	virtual EModRet OnDeleteUser(CUser& User) override {
 		// Loop through each chan
 		for (set<CPartylineChannel*>::iterator it = m_ssChannels.begin(); it != m_ssChannels.end();) {
 			CPartylineChannel *pChan = *it;
@@ -188,7 +188,7 @@ public:
 		return CONTINUE;
 	}
 
-	virtual EModRet OnRaw(CString& sLine) {
+	virtual EModRet OnRaw(CString& sLine) override {
 		if (sLine.Token(1) == "005") {
 			CString::size_type uPos = sLine.AsUpper().find("CHANTYPES=");
 			if (uPos != CString::npos) {
@@ -198,72 +198,76 @@ public:
 					sLine.append(CHAN_PREFIX_1);
 				else
 					sLine.insert(uPos, CHAN_PREFIX_1);
-				m_spInjectedPrefixes.insert(m_pNetwork);
+				m_spInjectedPrefixes.insert(GetNetwork());
 			}
 		}
 
 		return CONTINUE;
 	}
 
-	virtual void OnIRCDisconnected() {
-		m_spInjectedPrefixes.erase(m_pNetwork);
+	virtual void OnIRCDisconnected() override {
+		m_spInjectedPrefixes.erase(GetNetwork());
 	}
 
-	virtual void OnClientLogin() {
-		if (m_spInjectedPrefixes.find(m_pNetwork) == m_spInjectedPrefixes.end() && m_pNetwork && !m_pNetwork->GetChanPrefixes().empty()) {
-			m_pClient->PutClient(":" + GetIRCServer(m_pNetwork) + " 005 " + m_pClient->GetNick() + " CHANTYPES=" + m_pNetwork->GetChanPrefixes() + CHAN_PREFIX_1 " :are supported by this server.");
+	virtual void OnClientLogin() override {
+		CUser* pUser = GetUser();
+		CClient* pClient = GetClient();
+		CIRCNetwork* pNetwork = GetNetwork();
+		if (m_spInjectedPrefixes.find(pNetwork) == m_spInjectedPrefixes.end() && pNetwork && !pNetwork->GetChanPrefixes().empty()) {
+			pClient->PutClient(":" + GetIRCServer(pNetwork) + " 005 " + pClient->GetNick() + " CHANTYPES=" + pNetwork->GetChanPrefixes() + CHAN_PREFIX_1 " :are supported by this server.");
 		}
 
 		// Make sure this user is in the default channels
 		for (set<CString>::iterator a = m_ssDefaultChans.begin(); a != m_ssDefaultChans.end(); ++a) {
 			CPartylineChannel* pChannel = GetChannel(*a);
-			const CString& sNick = m_pUser->GetUserName();
+			const CString& sNick = pUser->GetUserName();
 
 			if (pChannel->IsInChannel(sNick))
 				continue;
 
-			CString sHost = m_pUser->GetBindHost();
+			CString sHost = pUser->GetBindHost();
 			const set<CString>& ssNicks = pChannel->GetNicks();
 
 			if (sHost.empty()) {
 				sHost = "znc.in";
 			}
-			PutChan(ssNicks, ":" + NICK_PREFIX + sNick + "!" + m_pUser->GetIdent() + "@" + sHost + " JOIN " + *a, false);
+			PutChan(ssNicks, ":" + NICK_PREFIX + sNick + "!" + pUser->GetIdent() + "@" + sHost + " JOIN " + *a, false);
 			pChannel->AddNick(sNick);
 		}
 
-		CString sNickMask = m_pClient->GetNickMask();
+		CString sNickMask = pClient->GetNickMask();
 
 		for (set<CPartylineChannel*>::iterator it = m_ssChannels.begin(); it != m_ssChannels.end(); ++it) {
 			const set<CString>& ssNicks = (*it)->GetNicks();
 
-			if ((*it)->IsInChannel(m_pUser->GetUserName())) {
+			if ((*it)->IsInChannel(pUser->GetUserName())) {
 
-				m_pClient->PutClient(":" + sNickMask + " JOIN " + (*it)->GetName());
+				pClient->PutClient(":" + sNickMask + " JOIN " + (*it)->GetName());
 
 				if (!(*it)->GetTopic().empty()) {
-					m_pClient->PutClient(":" + GetIRCServer(m_pNetwork) + " 332 " + m_pClient->GetNickMask() + " " + (*it)->GetName() + " :" + (*it)->GetTopic());
+					pClient->PutClient(":" + GetIRCServer(pNetwork) + " 332 " + pClient->GetNickMask() + " " + (*it)->GetName() + " :" + (*it)->GetTopic());
 				}
 
-				SendNickList(m_pUser, m_pNetwork, ssNicks, (*it)->GetName());
-				PutChan(ssNicks, ":*" + GetModName() + "!znc@znc.in MODE " + (*it)->GetName() + " +" + CString(m_pUser->IsAdmin() ? "o" : "v") + " " + NICK_PREFIX + m_pUser->GetUserName(), false);
+				SendNickList(pUser, pNetwork, ssNicks, (*it)->GetName());
+				PutChan(ssNicks, ":*" + GetModName() + "!znc@znc.in MODE " + (*it)->GetName() + " +" + CString(pUser->IsAdmin() ? "o" : "v") + " " + NICK_PREFIX + pUser->GetUserName(), false);
 			}
 		}
 	}
 
-	virtual void OnClientDisconnect() {
-		if (!m_pUser->IsUserAttached() && !m_pUser->IsBeingDeleted()) {
+	virtual void OnClientDisconnect() override {
+		CUser* pUser = GetUser();
+		if (!pUser->IsUserAttached() && !pUser->IsBeingDeleted()) {
 			for (set<CPartylineChannel*>::iterator it = m_ssChannels.begin(); it != m_ssChannels.end(); ++it) {
 				const set<CString>& ssNicks = (*it)->GetNicks();
 
-				if (ssNicks.find(m_pUser->GetUserName()) != ssNicks.end()) {
-					PutChan(ssNicks, ":*" + GetModName() + "!znc@znc.in MODE " + (*it)->GetName() + " -ov " + NICK_PREFIX + m_pUser->GetUserName() + " " + NICK_PREFIX + m_pUser->GetUserName(), false);
+				if (ssNicks.find(pUser->GetUserName()) != ssNicks.end()) {
+					PutChan(ssNicks, ":*" + GetModName() + "!znc@znc.in MODE " + (*it)->GetName() + " -ov " + NICK_PREFIX + pUser->GetUserName() + " " + NICK_PREFIX + pUser->GetUserName(), false);
 				}
 			}
 		}
 	}
 
-	virtual EModRet OnUserRaw(CString& sLine) {
+	virtual EModRet OnUserRaw(CString& sLine) override {
 		if (sLine.Equals("WHO " CHAN_PREFIX_1, false, 5)) {
 			return HALT;
 		} else if (sLine.Equals("MODE " CHAN_PREFIX_1, false, 6)) {
@@ -274,29 +278,31 @@ public:
 
 			sTopic.TrimPrefix(":");
 
+			CUser* pUser = GetUser();
+			CClient* pClient = GetClient();
 			CPartylineChannel* pChannel = FindChannel(sChannel);
 
-			if (pChannel && pChannel->IsInChannel(m_pUser->GetUserName())) {
+			if (pChannel && pChannel->IsInChannel(pUser->GetUserName())) {
 				const set<CString>& ssNicks = pChannel->GetNicks();
 				if (!sTopic.empty()) {
-					if (m_pUser->IsAdmin()) {
-						PutChan(ssNicks, ":" + m_pClient->GetNickMask() + " TOPIC " + sChannel + " :" + sTopic);
+					if (pUser->IsAdmin()) {
+						PutChan(ssNicks, ":" + pClient->GetNickMask() + " TOPIC " + sChannel + " :" + sTopic);
 						pChannel->SetTopic(sTopic);
 						SaveTopic(pChannel);
 					} else {
-						m_pUser->PutUser(":irc.znc.in 482 " +  m_pClient->GetNick() + " " + sChannel + " :You're not channel operator");
+						pUser->PutUser(":irc.znc.in 482 " +  pClient->GetNick() + " " + sChannel + " :You're not channel operator");
 					}
 				} else {
 					sTopic = pChannel->GetTopic();
 
 					if (sTopic.empty()) {
-						m_pUser->PutUser(":irc.znc.in 331 " + m_pClient->GetNick() + " " + sChannel + " :No topic is set.");
+						pUser->PutUser(":irc.znc.in 331 " + pClient->GetNick() + " " + sChannel + " :No topic is set.");
 					} else {
-						m_pUser->PutUser(":irc.znc.in 332 " + m_pClient->GetNick() + " " + sChannel + " :" + sTopic);
+						pUser->PutUser(":irc.znc.in 332 " + pClient->GetNick() + " " + sChannel + " :" + sTopic);
 					}
 				}
 			} else {
-				m_pUser->PutUser(":irc.znc.in 442 " + m_pClient->GetNick() + " " + sChannel + " :You're not on that channel");
+				pUser->PutUser(":irc.znc.in 442 " + pClient->GetNick() + " " + sChannel + " :You're not on that channel");
 			}
 			return HALT;
 		}
@@ -304,19 +310,19 @@ public:
 		return CONTINUE;
 	}
 
-	virtual EModRet OnUserPart(CString& sChannel, CString& sMessage) {
+	virtual EModRet OnUserPart(CString& sChannel, CString& sMessage) override {
 		if (sChannel.Left(1) != CHAN_PREFIX_1) {
 			return CONTINUE;
 		}
 
 		if (sChannel.Left(2) != CHAN_PREFIX) {
-			m_pClient->PutClient(":" + GetIRCServer(m_pNetwork) + " 401 " + m_pClient->GetNick() + " " + sChannel + " :No such channel");
+			GetClient()->PutClient(":" + GetIRCServer(GetNetwork()) + " 401 " + GetClient()->GetNick() + " " + sChannel + " :No such channel");
 			return HALT;
 		}
 
 		CPartylineChannel* pChannel = FindChannel(sChannel);
 
-		PartUser(m_pUser, pChannel);
+		PartUser(GetUser(), pChannel);
 
 		return HALT;
 	}
@@ -379,20 +385,20 @@ public:
 		}
 	}
 
-	virtual EModRet OnUserJoin(CString& sChannel, CString& sKey) {
+	virtual EModRet OnUserJoin(CString& sChannel, CString& sKey) override {
 		if (sChannel.Left(1) != CHAN_PREFIX_1) {
 			return CONTINUE;
 		}
 
 		if (sChannel.Left(2) != CHAN_PREFIX) {
-			m_pClient->PutClient(":" + GetIRCServer(m_pNetwork) + " 403 " + m_pClient->GetNick() + " " + sChannel + " :Channels look like " CHAN_PREFIX "znc");
+			GetClient()->PutClient(":" + GetIRCServer(GetNetwork()) + " 403 " + GetClient()->GetNick() + " " + sChannel + " :Channels look like " CHAN_PREFIX "znc");
 			return HALT;
 		}
 
 		sChannel = sChannel.Left(32);
 		CPartylineChannel* pChannel = GetChannel(sChannel);
 
-		JoinUser(m_pUser, pChannel);
+		JoinUser(GetUser(), pChannel);
 
 		return HALT;
 	}
@@ -437,7 +443,7 @@ public:
 		}
 	}
 
-	virtual EModRet HandleMessage(const CString& sCmd, const CString& sTarget, const CString& sMessage) {
+	EModRet HandleMessage(const CString& sCmd, const CString& sTarget, const CString& sMessage) {
 		if (sTarget.empty()) {
 			return CONTINUE;
 		}
@@ -448,7 +454,10 @@ public:
 			return CONTINUE;
 		}
 
-		CString sHost = m_pUser->GetBindHost();
+		CUser* pUser = GetUser();
+		CClient* pClient = GetClient();
+		CIRCNetwork* pNetwork = GetNetwork();
+		CString sHost = pUser->GetBindHost();
 
 		if (sHost.empty()) {
 			sHost = "znc.in";
@@ -456,53 +465,53 @@ public:
 
 		if (cPrefix == CHAN_PREFIX_1C) {
 			if (FindChannel(sTarget) == NULL) {
-				m_pClient->PutClient(":" + GetIRCServer(m_pNetwork) + " 401 " + m_pClient->GetNick() + " " + sTarget + " :No such channel");
+				pClient->PutClient(":" + GetIRCServer(pNetwork) + " 401 " + pClient->GetNick() + " " + sTarget + " :No such channel");
 				return HALT;
 			}
 
-			PutChan(sTarget, ":" + NICK_PREFIX + m_pUser->GetUserName() + "!" + m_pUser->GetIdent() + "@" + sHost + " " + sCmd + " " + sTarget + " :" + sMessage, true, false);
+			PutChan(sTarget, ":" + NICK_PREFIX + pUser->GetUserName() + "!" + pUser->GetIdent() + "@" + sHost + " " + sCmd + " " + sTarget + " :" + sMessage, true, false);
 		} else {
 			CString sNick = sTarget.LeftChomp_n(1);
-			CUser* pUser = CZNC::Get().FindUser(sNick);
+			CUser* pTargetUser = CZNC::Get().FindUser(sNick);
 
-			if (pUser) {
-				vector<CClient*> vClients = pUser->GetAllClients();
+			if (pTargetUser) {
+				vector<CClient*> vClients = pTargetUser->GetAllClients();
 
 				if (vClients.empty()) {
-					m_pClient->PutClient(":" + GetIRCServer(m_pNetwork) + " 401 " + m_pClient->GetNick() + " " + sTarget + " :User is not attached: " + sNick + "");
+					pClient->PutClient(":" + GetIRCServer(pNetwork) + " 401 " + pClient->GetNick() + " " + sTarget + " :User is not attached: " + sNick + "");
 					return HALT;
 				}
 
 				for (vector<CClient*>::const_iterator it = vClients.begin(); it != vClients.end(); ++it) {
-					CClient* pClient = *it;
+					CClient* pTarget = *it;
 
-					pClient->PutClient(":" + NICK_PREFIX + m_pUser->GetUserName() + "!" + m_pUser->GetIdent() + "@" + sHost + " " + sCmd + " " + pClient->GetNick() + " :" + sMessage);
+					pTarget->PutClient(":" + NICK_PREFIX + pUser->GetUserName() + "!" + pUser->GetIdent() + "@" + sHost + " " + sCmd + " " + pTarget->GetNick() + " :" + sMessage);
 				}
 			} else {
-				m_pClient->PutClient(":" + GetIRCServer(m_pNetwork) + " 401 " + m_pClient->GetNick() + " " + sTarget + " :No such znc user: " + sNick + "");
+				pClient->PutClient(":" + GetIRCServer(pNetwork) + " 401 " + pClient->GetNick() + " " + sTarget + " :No such znc user: " + sNick + "");
 			}
 		}
 
 		return HALT;
 	}
 
-	virtual EModRet OnUserMsg(CString& sTarget, CString& sMessage) {
+	virtual EModRet OnUserMsg(CString& sTarget, CString& sMessage) override {
 		return HandleMessage("PRIVMSG", sTarget, sMessage);
 	}
 
-	virtual EModRet OnUserNotice(CString& sTarget, CString& sMessage) {
+	virtual EModRet OnUserNotice(CString& sTarget, CString& sMessage) override {
 		return HandleMessage("NOTICE", sTarget, sMessage);
 	}
 
-	virtual EModRet OnUserAction(CString& sTarget, CString& sMessage) {
+	virtual EModRet OnUserAction(CString& sTarget, CString& sMessage) override {
 		return HandleMessage("PRIVMSG", sTarget, "\001ACTION " + sMessage + "\001");
 	}
 
-	virtual EModRet OnUserCTCP(CString& sTarget, CString& sMessage) {
+	virtual EModRet OnUserCTCP(CString& sTarget, CString& sMessage) override {
 		return HandleMessage("PRIVMSG", sTarget, "\001" + sMessage + "\001");
 	}
 
-	virtual EModRet OnUserCTCPReply(CString& sTarget, CString& sMessage) {
+	virtual EModRet OnUserCTCPReply(CString& sTarget, CString& sMessage) override {
 		return HandleMessage("NOTICE", sTarget, "\001" + sMessage + "\001");
 	}
 
@@ -532,9 +541,9 @@ public:
 		const map<CString, CUser*>& msUsers = CZNC::Get().GetUserMap();
 
 		if (!pUser)
-			pUser = m_pUser;
+			pUser = GetUser();
 		if (!pClient)
-			pClient = m_pClient;
+			pClient = GetClient();
 
 		for (map<CString, CUser*>::const_iterator it = msUsers.begin(); it != msUsers.end(); ++it) {
 			if (ssNicks.find(it->first) != ssNicks.end()) {
