@@ -422,7 +422,13 @@ bool CIRCNetwork::ParseConfig(CConfig *pConfig, CString& sError, bool bUpgrade)
 				// XXX The awaynick module was retired in 1.6 (still available as external module)
 				if (sModName == "awaynick") {
 					// load simple_away instead, unless it's already on the list
-					if (std::find(vsList.begin(), vsList.end(), "simple_away") == vsList.end()) {
+					bool bFound = false;
+					for (const CString& sLoadMod : vsList) {
+						if (sLoadMod.Token(0).Equals("simple_away")) {
+							bFound = true;
+						}
+					}
+					if (!bFound) {
 						sNotice = "Loading network module [simple_away] instead";
 						sModName = "simple_away";
 						// not a fatal error if simple_away is not available
@@ -466,6 +472,7 @@ bool CIRCNetwork::ParseConfig(CConfig *pConfig, CString& sError, bool bUpgrade)
 			CUtils::PrintError(sError);
 
 			CZNC::DumpConfig(pSubConf);
+			delete pChan;
 			return false;
 		}
 
@@ -1385,6 +1392,9 @@ void CIRCNetwork::SetBindHost(const CString& s) {
 
 void CIRCNetwork::SetEncoding(const CString& s) {
 	m_sEncoding = s;
+	if (GetIRCSock()) {
+		GetIRCSock()->SetEncoding(s);
+	}
 }
 
 void CIRCNetwork::SetQuitMsg(const CString& s) {
